@@ -1,5 +1,30 @@
-# logger.py
-"""PyCMTensor logger module"""
+"""PyCMTensor logger module
+
+This module sets the logging state of the program. Verbosity is defined by `set_level()`
+
+## Example Usage
+```python
+# Set the logger level to DEBUG
+set_level(DEBUG)
+
+# Get the effective level of the logger
+level = get_effective_level()
+
+# Log a message at the INFO level
+info("This is an informational message")
+
+# Log a message at the WARNING level
+warning("This is a warning message")
+```
+
+## Inputs
+- `level` (int): The level of the logger to be set. It can be one of the predefined 
+  levels: `DEBUG`, `INFO`, `WARNING`, `ERROR`, or `CRITICAL`.
+
+## Outputs
+- None
+"""
+
 import logging
 
 __all__ = [
@@ -23,7 +48,16 @@ CRITICAL = logging.CRITICAL
 
 
 def set_level(level):
-    """Set the level of the logger"""
+    """Set the level of the logger. The higher the number, the higher the verbosity.
+
+    Args:
+        level (int): the level of the logger
+            - `DEBUG` = 10
+            - `INFO` = 20 (DEFAULT)
+            - `WARNING` = 30
+            - `ERROR` = 40
+            - `CRITICAL` = 50
+    """
     main_logger.setLevel(level)
 
 
@@ -53,9 +87,9 @@ def get_default_logger(name, level):
 
 
 default_formatter = logging.Formatter(
-    "[{asctime:s}] {levelname:s}: {message:s}",
+    "{asctime:s} [{levelname:s}] {message:s}",
     style="{",
-    datefmt="%Y-%m-%d %H:%M:%S",
+    datefmt="%H:%M:%S",
 )
 
 main_logger = get_default_logger("pycmtensor", VERBOSITY_DEFAULT)
